# Form implementation generated from reading ui file '/home/joe/Projects/imagetopixel/airunner/src/airunner/pyqt/model_merger_model.ui'
#
# Created by: PyQt6 UI code generator 6.4.2
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        Form.resize(430, 200)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Preferred, QtWidgets.QSizePolicy.Policy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Form.sizePolicy().hasHeightForWidth())
        Form.setSizePolicy(sizePolicy)
        Form.setMinimumSize(QtCore.QSize(0, 100))
        self.gridLayout = QtWidgets.QGridLayout(Form)
        self.gridLayout.setObjectName("gridLayout")
        self.models = QtWidgets.QComboBox(parent=Form)
        self.models.setObjectName("models")
        self.gridLayout.addWidget(self.models, 1, 0, 1, 1)
        self.model_label = QtWidgets.QLabel(parent=Form)
        font = QtGui.QFont()
        font.setBold(True)
        self.model_label.setFont(font)
        self.model_label.setObjectName("model_label")
        self.gridLayout.addWidget(self.model_label, 0, 0, 1, 1)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.model_weight_slider = QtWidgets.QSlider(parent=Form)
        self.model_weight_slider.setMaximum(100)
        self.model_weight_slider.setOrientation(QtCore.Qt.Orientation.Horizontal)
        self.model_weight_slider.setObjectName("model_weight_slider")
        self.horizontalLayout.addWidget(self.model_weight_slider)
        self.model_weight_spinbox = QtWidgets.QDoubleSpinBox(parent=Form)
        self.model_weight_spinbox.setMaximum(1.0)
        self.model_weight_spinbox.setObjectName("model_weight_spinbox")
        self.horizontalLayout.addWidget(self.model_weight_spinbox)
        self.gridLayout.addLayout(self.horizontalLayout, 2, 0, 1, 1)
        self.model_delete_button = QtWidgets.QPushButton(parent=Form)
        self.model_delete_button.setObjectName("model_delete_button")
        self.gridLayout.addWidget(self.model_delete_button, 3, 0, 1, 1)
        spacerItem = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.Expanding)
        self.gridLayout.addItem(spacerItem, 4, 0, 1, 1)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(_translate("Form", "Form"))
        self.model_label.setText(_translate("Form", "Model"))
        self.model_delete_button.setText(_translate("Form", "Remove Model"))
